@@ -30,8 +30,8 @@ change_grid(int vlistID1, int vlistID2, int gridID2)
 {
   auto gridsize2 = gridInqSize(gridID2);
   int found = 0;
-  auto ngrids = vlistNumGrids(vlistID1);
-  for (int index = 0; index < ngrids; ++index)
+  auto numGrids = vlistNumGrids(vlistID1);
+  for (int index = 0; index < numGrids; ++index)
     {
       if (gridsize2 == gridInqSize(vlistGrid(vlistID1, index)))
         {
@@ -49,8 +49,8 @@ grid_set_type(int vlistID1, int vlistID2, int gridtype, const std::string &gridn
   auto needCorners = withBounds ? NeedCorners::Yes : NeedCorners::No;
   int gridID2;
   auto lrgrid = false;
-  auto ngrids = vlistNumGrids(vlistID1);
-  for (int index = 0; index < ngrids; ++index)
+  auto numGrids = vlistNumGrids(vlistID1);
+  for (int index = 0; index < numGrids; ++index)
     {
       auto gridID1 = vlistGrid(vlistID1, index);
       auto gridtype1 = gridInqType(gridID1);
@@ -141,8 +141,8 @@ grid_set_cellarea(int vlistID1, int vlistID2, Varray<double> &gridcellArea)
 {
   auto areasize = gridcellArea.size();
   int numGridsChanges = 0;
-  auto ngrids = vlistNumGrids(vlistID1);
-  for (int index = 0; index < ngrids; ++index)
+  auto numGrids = vlistNumGrids(vlistID1);
+  for (int index = 0; index < numGrids; ++index)
     {
       auto gridID1 = vlistGrid(vlistID1, index);
       auto gridsize = gridInqSize(gridID1);
@@ -158,11 +158,11 @@ grid_set_cellarea(int vlistID1, int vlistID2, Varray<double> &gridcellArea)
 }
 
 static void
-grid_set_mask(int vlistID1, int vlistID2, Varray<double> &gridmask)
+grid_set_mask(int vlistID1, int vlistID2, const Varray<double> &gridmask)
 {
   auto masksize = gridmask.size();
-  auto ngrids = vlistNumGrids(vlistID1);
-  for (int index = 0; index < ngrids; ++index)
+  auto numGrids = vlistNumGrids(vlistID1);
+  for (int index = 0; index < numGrids; ++index)
     {
       auto gridID1 = vlistGrid(vlistID1, index);
       auto gridsize = gridInqSize(gridID1);
@@ -183,8 +183,8 @@ grid_set_mask(int vlistID1, int vlistID2, Varray<double> &gridmask)
 static void
 grid_unset_mask(int vlistID1, int vlistID2)
 {
-  auto ngrids = vlistNumGrids(vlistID1);
-  for (int index = 0; index < ngrids; ++index)
+  auto numGrids = vlistNumGrids(vlistID1);
+  for (int index = 0; index < numGrids; ++index)
     {
       auto gridID1 = vlistGrid(vlistID1, index);
       auto gridID2 = gridDuplicate(gridID1);
@@ -196,8 +196,8 @@ grid_unset_mask(int vlistID1, int vlistID2)
 static void
 grid_set_proj_params(int vlistID1, int vlistID2, const std::string &projparams)
 {
-  auto ngrids = vlistNumGrids(vlistID1);
-  for (int index = 0; index < ngrids; ++index)
+  auto numGrids = vlistNumGrids(vlistID1);
+  for (int index = 0; index < numGrids; ++index)
     {
       auto gridID1 = vlistGrid(vlistID1, index);
       if (gridInqType(gridID1) == GRID_PROJECTION)
@@ -248,17 +248,17 @@ grid_read_cellarea(const std::string &areafile, Varray<double> &gridcellArea)
       if (varID == nvars) cdo_abort("Variable %s not found in %s\n", varname, filename);
     }
 
-  auto nrecs = streamInqTimestep(streamID, 0);
-  for (int recID = 0; recID < nrecs; ++recID)
+  auto numFields = streamInqTimestep(streamID, 0);
+  for (int fieldID = 0; fieldID < numFields; ++fieldID)
     {
       int varID, levelID;
-      streamInqRecord(streamID, &varID, &levelID);
+      streamInqField(streamID, &varID, &levelID);
       if (varID == svarID)
         {
           gridcellArea.resize(varList.vars[varID].gridsize);
 
           size_t numMissVals;
-          streamReadRecord(streamID, gridcellArea.data(), &numMissVals);
+          streamReadField(streamID, gridcellArea.data(), &numMissVals);
           break;
         }
     }
@@ -363,14 +363,14 @@ public:
 
         (void) streamInqTimestep(streamID, 0);
         int varID, levelID;
-        streamInqRecord(streamID, &varID, &levelID);
+        streamInqField(streamID, &varID, &levelID);
         auto missval = varList.vars[varID].missval;
         auto gridID = varList.vars[varID].gridID;
         auto masksize = gridInqSize(gridID);
         gridmask.resize(masksize);
 
         size_t numMissVals;
-        streamReadRecord(streamID, gridmask.data(), &numMissVals);
+        streamReadField(streamID, gridmask.data(), &numMissVals);
         streamClose(streamID);
 
         for (size_t i = 0; i < masksize; ++i)
@@ -471,7 +471,6 @@ public:
     else if (operatorID == SETPROJPARAMS) { grid_set_proj_params(vlistID1, vlistID2, projparams); }
 
     streamID2 = cdo_open_write(1);
-
     cdo_def_vlist(streamID2, vlistID2);
     // vlistPrint(vlistID2);
 
@@ -490,22 +489,21 @@ public:
     int tsID = 0;
     while (true)
       {
-        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-        if (nrecs == 0) break;
+        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+        if (numFields == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
         cdo_def_timestep(streamID2, tsID);
 
-        for (int recID = 0; recID < nrecs; ++recID)
+        for (int fieldID = 0; fieldID < numFields; ++fieldID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            cdo_def_record(streamID2, varID, levelID);
+            auto [varID, levelID] = cdo_inq_field(streamID1);
+            cdo_def_field(streamID2, varID, levelID);
 
             const auto &var1 = varList1.vars[varID];
             const auto &var2 = varList2.vars[varID];
             field.init((lregular || lregularnn) ? var2 : var1);
-            cdo_read_record(streamID1, field);
+            cdo_read_field(streamID1, field);
             auto numMissVals = field.numMissVals;
 
             auto gridID1 = var1.gridID;
@@ -515,26 +513,20 @@ public:
                   {
                     auto missval = var1.missval;
                     int lnearst = lregularnn ? 1 : 0;
-                    field2regular(gridID1, var2.gridID, missval, field.vec_d.data(), numMissVals, lnearst);
+                    field2regular(gridID1, var2.gridID, missval, field.vec_d, numMissVals, lnearst);
                   }
               }
             else if (gridInqType(gridID1) == GRID_GME)
               {
-                auto gridsize = var1.gridsize;
-                size_t j = 0;
-                if (field.memType == MemType::Float)
-                  {
-                    for (size_t i = 0; i < gridsize; ++i)
-                      if (grid2_vgpm[i]) field.vec_f[j++] = field.vec_f[i];
-                  }
-                else
-                  {
-                    for (size_t i = 0; i < gridsize; ++i)
-                      if (grid2_vgpm[i]) field.vec_d[j++] = field.vec_d[i];
-                  }
+                auto n = var1.gridsize;
+                auto func = [&](auto &v) {
+                  for (size_t i = 0, j = 0; i < n; ++i)
+                    if (grid2_vgpm[i]) v[j++] = v[i];
+                };
+                field_operation(func, field);
               }
 
-            cdo_write_record(streamID2, field);
+            cdo_write_field(streamID2, field);
           }
         tsID++;
       }
