@@ -16,7 +16,7 @@ public:
   using Process::Process;
   inline static CdoModule module = {
     .name = "Tocomplex",
-    .operators = { { "retocomplex"}, { "imtocomplex"} },
+    .operators = { { "retocomplex" }, { "imtocomplex" } },
     .aliases = {},
     .mode = EXPOSED,     // Module mode: 0:intern 1:extern
     .number = CDI_REAL,  // Allowed number type
@@ -34,7 +34,6 @@ public:
   int operatorID;
 
   VarList varList1;
-  Varray<double> array1, array2;
 
 public:
   void
@@ -68,33 +67,32 @@ public:
     streamID2 = cdo_open_write(1);
     cdo_def_vlist(streamID2, vlistID2);
 
-    auto gridsizemax = vlistGridsizeMax(vlistID1);
-    array1 = Varray<double>(gridsizemax);
-    array2 = Varray<double>(2 * gridsizemax);
-
     varList1 = VarList(vlistID1);
   }
 
   void
   run() override
   {
+    Varray<double> array1(varList1.gridsizeMax());
+    Varray<double> array2(2 * varList1.gridsizeMax());
+
     int tsID = 0;
     int tsID2 = 0;
     while (true)
       {
-        auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-        if (nrecs == 0) break;
+        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+        if (numFields == 0) break;
 
         cdo_taxis_copy_timestep(taxisID2, taxisID1);
         cdo_def_timestep(streamID2, tsID2++);
 
-        for (int recID = 0; recID < nrecs; ++recID)
+        for (int fieldID = 0; fieldID < numFields; ++fieldID)
           {
-            auto [varID, levelID] = cdo_inq_record(streamID1);
-            cdo_def_record(streamID2, varID, levelID);
+            auto [varID, levelID] = cdo_inq_field(streamID1);
+            cdo_def_field(streamID2, varID, levelID);
 
             size_t numMissVals;
-            cdo_read_record(streamID1, array1.data(), &numMissVals);
+            cdo_read_field(streamID1, array1.data(), &numMissVals);
 
             auto gridsize = varList1.vars[varID].gridsize;
             if (operatorID == RETOCOMPLEX)
@@ -114,7 +112,7 @@ public:
                   }
               }
 
-            cdo_write_record(streamID2, array2.data(), numMissVals);
+            cdo_write_field(streamID2, array2.data(), numMissVals);
           }
 
         tsID++;
