@@ -121,8 +121,8 @@ zaxis_is_hybrid(int zaxisType)
 static void
 change_hybrid_zaxis(int vlistID1, int vlistID2, int vctSize, const double *vct, int zaxisID2, int numFullLevels, int numHalfLevels)
 {
-  auto nzaxis = vlistNumZaxis(vlistID1);
-  for (int iz = 0; iz < nzaxis; ++iz)
+  auto numZaxes = vlistNumZaxis(vlistID1);
+  for (int iz = 0; iz < numZaxes; ++iz)
     {
       auto zaxisID = vlistZaxis(vlistID1, iz);
       auto nlevels = zaxisInqSize(zaxisID);
@@ -142,7 +142,7 @@ print_vars_found(const VarIDs &varIDs, const CdoVars &vars)
 {
   cdo_print("Found:");
   // clang-format off
-  if (-1 != varIDs.tempID)    cdo_print("  %s -> %s", var_stdname(air_temperature), vars[varIDs.tempID].name);
+  if (-1 != varIDs.taID)    cdo_print("  %s -> %s", var_stdname(air_temperature), vars[varIDs.taID].name);
   if (-1 != varIDs.psID)      cdo_print("  %s -> %s", var_stdname(surface_air_pressure), vars[varIDs.psID].name);
   if (-1 != varIDs.lnpsID)    cdo_print("  LOG(%s) -> %s", var_stdname(surface_air_pressure), vars[varIDs.lnpsID].name);
   if (-1 != varIDs.sgeopotID) cdo_print("  %s -> %s", var_stdname(surface_geopotential), vars[varIDs.sgeopotID].name);
@@ -311,7 +311,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
       if (needVertIndexHalf) vertIndex_HL.resize(num3D);
     }
 
-  if (zaxisID_ML != -1 && varIDs.gheightID != -1 && varIDs.tempID == -1)
+  if (zaxisID_ML != -1 && varIDs.gheightID != -1 && varIDs.taID == -1)
     cdo_abort("%s not found, needed for vertical interpolation of %s!", var_stdname(air_temperature),
               var_stdname(geopotential_height));
 
@@ -334,7 +334,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
   Field psProg;
   if (zaxisID_ML != -1 && presID != -1) psProg.init(varList1.vars[presID]);
 
-  auto sgeopotNeeded = (varIDs.tempID != -1 || varIDs.gheightID != -1);
+  auto sgeopotNeeded = (varIDs.taID != -1 || varIDs.gheightID != -1);
 
   Field sgeopot;
   if (zaxisID_ML != -1 && sgeopotNeeded)
@@ -359,22 +359,22 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
   int tsID = 0;
   while (true)
     {
-      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
 
       for (int varID = 0; varID < numVars; ++varID) processVars[varID] = false;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
       cdo_def_timestep(streamID2, tsID);
 
-      for (int recID = 0; recID < nrecs; ++recID)
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
         {
-          auto [varID, levelID] = cdo_inq_record(streamID1);
+          auto [varID, levelID] = cdo_inq_field(streamID1);
           const auto &var = varList1.vars[varID];
 
           if (vctIsInverted && zaxisID_ML != -1 && var.zaxisID == zaxisID_ML) levelID = var.nlevels - 1 - levelID;
 
-          cdo_read_record(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
+          cdo_read_field(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
 
           processVars[varID] = true;
         }
@@ -430,7 +430,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
                       if (varnumMissVals[varID][levelID]) cdo_abort("Missing values unsupported for this operator!");
                     }
 
-                  if (varID == varIDs.tempID)
+                  if (varID == varIDs.taID)
                     {
                       if (var.nlevels == numHalfLevels) cdo_abort("Temperature on half level unsupported!");
 
@@ -443,7 +443,7 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
                       field_check_sgeopot(memType, gridsize, var.nlevels, sgeopot, vardata1[varID]);
 
                       vertical_interp_Z(numFullLevels, pressure_FL, pressure_HL, vardata1[varID], vardata2[varID],
-                                        vardata1[varIDs.tempID], sgeopot, vertIndex_FL, pressureLevels, gridsize);
+                                        vardata1[varIDs.taID], sgeopot, vertIndex_FL, pressureLevels, gridsize);
                     }
                   else
                     {
@@ -457,8 +457,8 @@ pressure_level_interpolation(Varray<double> &pressureLevels, bool useHeightLevel
 
               for (int levelID = 0; levelID < varList2.vars[varID].nlevels; ++levelID)
                 {
-                  cdo_def_record(streamID2, varID, levelID);
-                  cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
+                  cdo_def_field(streamID2, varID, levelID);
+                  cdo_write_field(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
                                    varnumMissVals[varID][levelID]);
                 }
             }
@@ -612,18 +612,18 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
   int tsID = 0;
   while (true)
     {
-      auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-      if (nrecs == 0) break;
+      auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+      if (numFields == 0) break;
 
       for (int varID = 0; varID < numVars; ++varID) processVars[varID] = false;
 
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
       cdo_def_timestep(streamID2, tsID);
 
-      for (int recID = 0; recID < nrecs; ++recID)
+      for (int fieldID = 0; fieldID < numFields; ++fieldID)
         {
-          auto [varID, levelID] = cdo_inq_record(streamID1);
-          cdo_read_record(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
+          auto [varID, levelID] = cdo_inq_field(streamID1);
+          cdo_read_field(streamID1, vardata1[varID], levelID, &varnumMissVals[varID][levelID]);
 
           processVars[varID] = true;
         }
@@ -665,8 +665,8 @@ height_level_interpolation(Varray<double> &heightLevels, bool extrapolate)
 
               for (int levelID = 0; levelID < varList2.vars[varID].nlevels; ++levelID)
                 {
-                  cdo_def_record(streamID2, varID, levelID);
-                  cdo_write_record(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
+                  cdo_def_field(streamID2, varID, levelID);
+                  cdo_write_field(streamID2, interpVars[varID] ? vardata2[varID] : vardata1[varID], levelID,
                                    varnumMissVals[varID][levelID]);
                 }
             }
