@@ -16,7 +16,6 @@
 
 #include <cdi.h>
 
-#include "cdo_options.h"
 #include "cdo_vlist.h"
 #include "datetime.h"
 #include "process_int.h"
@@ -24,46 +23,41 @@
 #include "percentiles_hist.h"
 #include "field_functions.h"
 
-class ModuleYdaypctl
+class Ydaypctl : public Process
 {
+public:
+  using Process::Process;
+  inline static CdoModule module = {
+    .name = "Ydaypctl",
+    .operators = { { "ydaypctl", FieldFunc_Pctl, 0, YdaypctlHelp } },
+    .aliases = {},
+    .mode = EXPOSED,     // Module mode: 0:intern 1:extern
+    .number = CDI_REAL,  // Allowed number type
+    .constraints = { 3, 1, NoRestriction },
+  };
+  inline static RegisterEntry<Ydaypctl> registration = RegisterEntry<Ydaypctl>(module);
+
   static const int MaxDays = 373;
-  CdiDateTime vDateTimes1[MaxDays]{};
-  CdiDateTime vDateTimes2[MaxDays]{};
-  long numSets[MaxDays] = { 0 };
-  std::vector<bool> vars1;
-  HistogramSet hsets[MaxDays];
 
   CdoStreamID streamID1;
-  int taxisID1;
-
   CdoStreamID streamID2;
-  int taxisID2;
-
   CdoStreamID streamID3;
-  int taxisID3;
-
   CdoStreamID streamID4;
-  int taxisID4;
 
-  int nvars;
-  int ntsteps;
-  int maxrecs;
+  int vlistID1;
+  int taxisID1;
+  int taxisID2;
+  int taxisID3;
+  int taxisID4;
 
   double pn;
 
-  Field field1, field2;
-
   VarList varList1;
-  FieldVector constFields;
-  std::vector<RecordInfo> recList;
 
 public:
   void
-  init(void *process)
+  init() override
   {
-    cdo_initialize(process);
-    cdo_operator_add("ydaypctl", FieldFunc_Pctl, 0, nullptr);
-
     operator_input_arg("percentile number");
     pn = parameter_to_double(cdo_operator_argv(0));
 
@@ -71,15 +65,19 @@ public:
     streamID2 = cdo_open_read(1);
     streamID3 = cdo_open_read(2);
 
-    const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-    const auto vlistID2 = cdo_stream_inq_vlist(streamID2);
-    const auto vlistID3 = cdo_stream_inq_vlist(streamID3);
-    const auto vlistID4 = vlistDuplicate(vlistID1);
+    vlistID1 = cdo_stream_inq_vlist(streamID1);
+    auto vlistID2 = cdo_stream_inq_vlist(streamID2);
+    auto vlistID3 = cdo_stream_inq_vlist(streamID3);
+    auto vlistID4 = vlistDuplicate(vlistID1);
 
     vlist_unpack(vlistID4);
 
-    vlist_compare(vlistID1, vlistID2, CmpVlist::All);
-    vlist_compare(vlistID1, vlistID3, CmpVlist::All);
+    varList1 = VarList(vlistID1);
+    VarList varList2(vlistID2);
+    VarList varList3(vlistID3);
+
+    varList_compare(varList1, varList2);
+    varList_compare(varList1, varList3);
 
     taxisID1 = vlistInqTaxis(vlistID1);
     taxisID2 = vlistInqTaxis(vlistID2);
@@ -92,35 +90,36 @@ public:
 
     streamID4 = cdo_open_write(3);
     cdo_def_vlist(streamID4, vlistID4);
-
-    ntsteps = vlistNtsteps(vlistID1);
-    nvars = vlistNvars(vlistID1);
-
-    maxrecs = vlistNrecs(vlistID1);
-    recList = std::vector<RecordInfo>(maxrecs);
-
-    constFields = FieldVector(maxrecs);
-
-    varList_init(varList1, vlistID1);
-
-    vars1 = std::vector<bool>(MaxDays, false);
   }
 
   void
-  run()
+  run() override
   {
+    Field field1, field2;
+    std::vector<bool> vars1(MaxDays, false);
+    CdiDateTime vDateTimes1[MaxDays]{};
+    CdiDateTime vDateTimes2[MaxDays]{};
+    HistogramSet hsets[MaxDays];
+    long numSets[MaxDays] = { 0 };
+
+    auto numVars = varList1.numVars();
+    auto numSteps = varList1.numSteps();
+    auto maxFields = varList1.maxFields();
+    std::vector<FieldInfo> fieldInfoList(maxFields);
+
+    FieldVector constFields(maxFields);
 
     int tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID2, tsID);
-        if (nrecs == 0) break;
+        auto numFields = cdo_stream_inq_timestep(streamID2, tsID);
+        if (numFields == 0) break;
 
-        if (nrecs != cdo_stream_inq_timestep(streamID3, tsID))
-          cdo_abort("Number of records at time step %d of %s and %s differ!", tsID + 1, cdo_get_stream_name(1),
+        if (numFields != cdo_stream_inq_timestep(streamID3, tsID))
+          cdo_abort("Number of fields at time step %d of %s and %s differ!", tsID + 1, cdo_get_stream_name(1),
                     cdo_get_stream_name(2));
 
-        const auto vDateTime = taxisInqVdatetime(taxisID2);
+        auto vDateTime = taxisInqVdatetime(taxisID2);
 
         if (cdiDateTime_isNE(vDateTime, taxisInqVdatetime(taxisID3)))
           cdo_abort("Verification dates at time step %d of %s and %s differ!", tsID + 1, cdo_get_stream_name(1),
@@ -128,7 +127,7 @@ public:
 
         // if (Options::cdoVerbose) cdo_print("process timestep: %d %s", tsID + 1, datetime_to_string(vDateTime));
 
-        const auto dayOfYear = decode_day_of_year(vDateTime.date);
+        auto dayOfYear = decode_day_of_year(vDateTime.date);
         if (dayOfYear < 0 || dayOfYear >= MaxDays) cdo_abort("Day %d out of range!", dayOfYear);
 
         vDateTimes2[dayOfYear] = vDateTime;
@@ -136,26 +135,21 @@ public:
         if (!vars1[dayOfYear])
           {
             vars1[dayOfYear] = true;
-            hsets[dayOfYear].create(nvars, ntsteps);
+            hsets[dayOfYear].create(numVars, numSteps);
 
-            for (int varID = 0; varID < nvars; ++varID)
-              {
-                const auto &var = varList1[varID];
-                hsets[dayOfYear].createVarLevels(varID, var.nlevels, var.gridsize);
-              }
+            for (const auto &var : varList1.vars) hsets[dayOfYear].createVarLevels(var.ID, var.nlevels, var.gridsize);
           }
 
-        for (int recID = 0; recID < nrecs; ++recID)
+        for (int fieldID = 0; fieldID < numFields; ++fieldID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID2, &varID, &levelID);
-            const auto &var = varList1[varID];
+            auto [varID, levelID] = cdo_inq_field(streamID2);
+            const auto &var = varList1.vars[varID];
             field1.init(var);
-            cdo_read_record(streamID2, field1);
+            cdo_read_field(streamID2, field1);
 
-            cdo_inq_record(streamID3, &varID, &levelID);
+            (void) cdo_inq_field(streamID3);
             field2.init(var);
-            cdo_read_record(streamID3, field2);
+            cdo_read_field(streamID3, field2);
 
             hsets[dayOfYear].defVarLevelBounds(varID, levelID, field1, field2);
           }
@@ -166,14 +160,14 @@ public:
     tsID = 0;
     while (true)
       {
-        const auto nrecs = cdo_stream_inq_timestep(streamID1, tsID);
-        if (nrecs == 0) break;
+        auto numFields = cdo_stream_inq_timestep(streamID1, tsID);
+        if (numFields == 0) break;
 
         const auto vDateTime = taxisInqVdatetime(taxisID1);
 
         // if (Options::cdoVerbose) cdo_print("process timestep: %d %s", tsID + 1, datetime_to_string(vDateTime));
 
-        const auto dayOfYear = decode_day_of_year(vDateTime.date);
+        auto dayOfYear = decode_day_of_year(vDateTime.date);
         if (dayOfYear < 0 || dayOfYear >= MaxDays) cdo_abort("Day %d out of range!", dayOfYear);
 
         vDateTimes1[dayOfYear] = vDateTime;
@@ -181,23 +175,22 @@ public:
         if (!vars1[dayOfYear])
           cdo_abort("No data for day %d in %s and %s", dayOfYear, cdo_get_stream_name(1), cdo_get_stream_name(2));
 
-        for (int recID = 0; recID < nrecs; ++recID)
+        for (int fieldID = 0; fieldID < numFields; ++fieldID)
           {
-            int varID, levelID;
-            cdo_inq_record(streamID1, &varID, &levelID);
-            const auto &var = varList1[varID];
+            auto [varID, levelID] = cdo_inq_field(streamID1);
+            const auto &var = varList1.vars[varID];
 
-            if (tsID == 0) recList[recID].set(varID, levelID);
+            if (tsID == 0) fieldInfoList[fieldID].set(varID, levelID);
 
             if (tsID == 0 && var.isConstant)
               {
-                constFields[recID].init(var);
-                cdo_read_record(streamID1, constFields[recID]);
+                constFields[fieldID].init(var);
+                cdo_read_field(streamID1, constFields[fieldID]);
               }
             else
               {
                 field1.init(var);
-                cdo_read_record(streamID1, field1);
+                cdo_read_field(streamID1, field1);
 
                 hsets[dayOfYear].addVarLevelValues(varID, levelID, field1);
               }
@@ -218,19 +211,20 @@ public:
           taxisDefVdatetime(taxisID4, vDateTimes1[dayOfYear]);
           cdo_def_timestep(streamID4, otsID);
 
-          for (int recID = 0; recID < maxrecs; ++recID)
+          for (int fieldID = 0; fieldID < maxFields; ++fieldID)
             {
-              auto [varID, levelID] = recList[recID].get();
-              if (otsID && varList1[varID].isConstant) continue;
+              auto [varID, levelID] = fieldInfoList[fieldID].get();
+              const auto &var = varList1.vars[varID];
+              if (otsID && var.isConstant) continue;
 
-              cdo_def_record(streamID4, varID, levelID);
+              cdo_def_field(streamID4, varID, levelID);
 
-              if (varList1[varID].isConstant) { cdo_write_record(streamID4, constFields[recID]); }
+              if (var.isConstant) { cdo_write_field(streamID4, constFields[fieldID]); }
               else
                 {
-                  field1.init(varList1[varID]);
+                  field1.init(var);
                   hsets[dayOfYear].getVarLevelPercentiles(field1, varID, levelID, pn);
-                  cdo_write_record(streamID4, field1);
+                  cdo_write_field(streamID4, field1);
                 }
             }
 
@@ -239,23 +233,11 @@ public:
   }
 
   void
-  close()
+  close() override
   {
     cdo_stream_close(streamID4);
     cdo_stream_close(streamID3);
     cdo_stream_close(streamID2);
     cdo_stream_close(streamID1);
-    cdo_finish();
   }
 };
-
-void *
-Ydaypctl(void *process)
-{
-  ModuleYdaypctl ydaypctl;
-  ydaypctl.init(process);
-  ydaypctl.run();
-  ydaypctl.close();
-
-  return nullptr;
-}
