@@ -27,25 +27,25 @@ limit_dphi_bounds(double &dphi)
 }
 
 std::pair<double, double>
-remap_find_weights(const LonLatPoint &llpoint, const SquareCorners &squareCorners)
+remap_find_weights(const PointLonLat &pointLL, const SquareCorners &squareCorners)
 {
   constexpr double converge = 1.0e-10;  // Convergence criterion
-  extern long remap_max_iter;
+  extern long RemapMaxIteration;
 
-  const auto &srcLons = squareCorners.lon;
-  const auto &srcLats = squareCorners.lat;
+  const auto &lons = squareCorners.lons;
+  const auto &lats = squareCorners.lats;
 
   // Iterate to find xfrac,yfrac for bilinear approximation
 
   // some latitude  differences
-  auto dth1 = srcLats[1] - srcLats[0];
-  auto dth2 = srcLats[3] - srcLats[0];
-  auto dth3 = srcLats[2] - srcLats[1] - dth2;
+  auto dth1 = lats[1] - lats[0];
+  auto dth2 = lats[3] - lats[0];
+  auto dth3 = lats[2] - lats[1] - dth2;
 
   // some longitude differences
-  auto dph1 = srcLons[1] - srcLons[0];
-  auto dph2 = srcLons[3] - srcLons[0];
-  auto dph3 = srcLons[2] - srcLons[1];
+  auto dph1 = lons[1] - lons[0];
+  auto dph2 = lons[3] - lons[0];
+  auto dph3 = lons[2] - lons[1];
 
   limit_dphi_bounds(dph1);
   limit_dphi_bounds(dph2);
@@ -58,10 +58,10 @@ remap_find_weights(const LonLatPoint &llpoint, const SquareCorners &squareCorner
   double yguess = 0.5;
 
   long iter = 0;  // iteration counters
-  for (iter = 0; iter < remap_max_iter; ++iter)
+  for (iter = 0; iter < RemapMaxIteration; ++iter)
     {
-      auto dthp = llpoint.lat - srcLats[0] - dth1 * xguess - dth2 * yguess - dth3 * xguess * yguess;
-      auto dphp = llpoint.lon - srcLons[0];
+      auto dthp = pointLL.get_lat() - lats[0] - dth1 * xguess - dth2 * yguess - dth3 * xguess * yguess;
+      auto dphp = pointLL.get_lon() - lons[0];
 
       limit_dphi_bounds(dphp);
 
@@ -83,7 +83,7 @@ remap_find_weights(const LonLatPoint &llpoint, const SquareCorners &squareCorner
       yguess += delj;
     }
 
-  if (iter >= remap_max_iter) xguess = yguess = -1.0;
+  if (iter >= RemapMaxIteration) xguess = yguess = -1.0;
 
   return std::make_pair(xguess, yguess);
 }
@@ -100,7 +100,7 @@ bilinear_set_weights(double xfrac, double yfrac, double (&weights)[4])
 }
 
 int
-num_src_points(const Varray<int8_t> &mask, const size_t (&indices)[4], double (&lats)[4])
+num_src_points(const Vmask &mask, const size_t (&indices)[4], double (&lats)[4])
 {
   int num = 4;
 
@@ -191,29 +191,29 @@ bilinear_warning()
 }
 
 static void
-remap_bilinear_weights_regular(RemapSearch &rsearch, const Varray<int8_t> &srcGridMask, const LonLatPoint &llpoint,
-                               double &tgtCellFrac, size_t tgtCellIndex, std::vector<WeightLinks> &weightLinks)
+remap_bilinear_weights_regular(RemapSearch &rsearch, const Vmask &srcGridMask, const PointLonLat &pointLL, double &tgtCellFrac,
+                               size_t tgtCellIndex, std::vector<WeightLinks> &weightLinks)
 {
   SquareCorners squareCorners;
   double weights[4];  //  bilinear weights for four corners
 
   // Find nearest square of grid points on source grid
-  auto searchResult = remap_search_square(rsearch, llpoint, squareCorners);
+  auto searchResult = remap_search_square(rsearch, pointLL, squareCorners);
 
   // Check to see if points are mask points
-  if (searchResult > 0) searchResult = remap_check_mask_indices(squareCorners.index, srcGridMask);
+  if (searchResult > 0) searchResult = remap_check_mask_indices(squareCorners.indices, srcGridMask);
 
   // If point found, find local xfrac/yfrac coordinates for weights
   if (searchResult > 0)
     {
       tgtCellFrac = 1.0;
 
-      auto [xfrac, yfrac] = remap_find_weights(llpoint, squareCorners);
+      auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
       if (xfrac >= 0.0 && yfrac >= 0.0)
         {
           // Successfully found xfrac, yfrac - compute weights
           bilinear_set_weights(xfrac, yfrac, weights);
-          store_weightlinks(0, 4, squareCorners.index, weights, tgtCellIndex, weightLinks);
+          store_weightlinks(0, 4, squareCorners.indices, weights, tgtCellIndex, weightLinks);
         }
       else
         {
@@ -222,36 +222,30 @@ remap_bilinear_weights_regular(RemapSearch &rsearch, const Varray<int8_t> &srcGr
         }
     }
 
-  /*
-    Search for bilinear failed - use a distance-weighted average instead
-    (this is typically near the pole) Distance was stored in srcLats!
-  */
+  // Search for bilinear failed - use a distance-weighted average instead
+  // (this is typically near the pole) Distance was stored in srcLats!
   if (searchResult < 0)
     {
-      if (num_src_points(srcGridMask, squareCorners.index, squareCorners.lat) > 0)
+      if (num_src_points(srcGridMask, squareCorners.indices, squareCorners.lats) > 0)
         {
           tgtCellFrac = 1.0;
-          renormalize_weights(squareCorners.lat, weights);
-          store_weightlinks(0, 4, squareCorners.index, weights, tgtCellIndex, weightLinks);
+          renormalize_weights(squareCorners.lats, weights);
+          store_weightlinks(0, 4, squareCorners.indices, weights, tgtCellIndex, weightLinks);
         }
     }
 }
 
 static void
-remap_bilinear_weights_healpix(const RemapSearch &rsearch, const Varray<int8_t> &srcGridMask, const LonLatPoint &llpoint,
+remap_bilinear_weights_healpix(const RemapSearch &rsearch, const Vmask &srcGridMask, const PointLonLat &pointLL,
                                double &tgtCellFrac, size_t tgtCellIndex, std::vector<WeightLinks> &weightLinks)
 {
-  auto nside = rsearch.srcGrid->nside;
-  auto order = rsearch.srcGrid->order;
+  double weights[4];  // bilinear weights for four corners
+  size_t indices[4];  // indices for the four source points
 
-  double weights[4];  //  bilinear weights for four corners
-  size_t indices[4];  //  indices for the four source points
-
-  hp_bilinear_interpolate_weights(llpoint.lon, llpoint.lat, indices, weights, nside, order);
+  hp_bilinear_interpolate_weights(rsearch.srcGrid->hpParams, pointLL.get_lon(), pointLL.get_lat(), indices, weights);
 
   // Check to see if points are mask points
-  int searchResult = remap_check_mask_indices(indices, srcGridMask);
-
+  auto searchResult = remap_check_mask_indices(indices, srcGridMask);
   if (searchResult > 0)
     {
       tgtCellFrac = 1.0;
@@ -260,7 +254,9 @@ remap_bilinear_weights_healpix(const RemapSearch &rsearch, const Varray<int8_t>
     }
 }
 
+// -----------------------------------------------------------------------
 // This routine computes the weights for a bilinear interpolation.
+// -----------------------------------------------------------------------
 void
 remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv)
 {
@@ -294,19 +290,20 @@ remap_bilinear_weights(RemapSearch &rsearch, RemapVars &rv)
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
       atomicCount++;
-      if (cdo_omp_get_thread_num() == 0) progress.update((double) atomicCount / tgtGridSize);
+      auto ompthID = cdo_omp_get_thread_num();
+      if (ompthID == 0 && tgtGridSize > progressMinSize) progress.update((double) atomicCount / tgtGridSize);
 
       weightLinks[tgtCellIndex].nlinks = 0;
 
       if (!tgtGrid->mask[tgtCellIndex]) continue;
 
-      auto llpoint = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
+      auto pointLL = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
 
-      auto &tgtCellFrac = tgtGrid->cell_frac[tgtCellIndex];
+      auto &tgtCellFrac = tgtGrid->cellFrac[tgtCellIndex];
       if (isHealpixGrid)
-        remap_bilinear_weights_healpix(rsearch, srcGrid->mask, llpoint, tgtCellFrac, tgtCellIndex, weightLinks);
+        remap_bilinear_weights_healpix(rsearch, srcGrid->mask, pointLL, tgtCellFrac, tgtCellIndex, weightLinks);
       else
-        remap_bilinear_weights_regular(rsearch, srcGrid->mask, llpoint, tgtCellFrac, tgtCellIndex, weightLinks);
+        remap_bilinear_weights_regular(rsearch, srcGrid->mask, pointLL, tgtCellFrac, tgtCellIndex, weightLinks);
     }
 
   weight_links_to_remap_links(0, tgtGridSize, weightLinks, rv);
@@ -325,28 +322,28 @@ bilinear_remap(const Varray<T> &srcArray, const double (&wgt)[4], const size_t (
 
 template <typename T1, typename T2>
 static void
-remap_bilinear_regular(RemapSearch &rsearch, const Varray<T1> &srcArray, const Varray<int8_t> &srcGridMask,
-                       const LonLatPoint &llpoint, T2 &tgtValue)
+remap_bilinear_regular(RemapSearch &rsearch, const Varray<T1> &srcArray, const Vmask &srcGridMask, const PointLonLat &pointLL,
+                       T2 &tgtValue)
 {
   SquareCorners squareCorners;
   double weights[4];  //  bilinear weights for four corners
 
   // Find nearest square of grid points on source grid
-  auto searchResult = remap_search_square(rsearch, llpoint, squareCorners);
+  auto searchResult = remap_search_square(rsearch, pointLL, squareCorners);
 
   // Check to see if points are mask points
-  if (searchResult > 0) searchResult = remap_check_mask_indices(squareCorners.index, srcGridMask);
+  if (searchResult > 0) searchResult = remap_check_mask_indices(squareCorners.indices, srcGridMask);
 
   // If point found, find local xfrac/yfrac coordinates for weights
   if (searchResult > 0)
     {
-      auto [xfrac, yfrac] = remap_find_weights(llpoint, squareCorners);
+      auto [xfrac, yfrac] = remap_find_weights(pointLL, squareCorners);
       if (xfrac >= 0.0 && yfrac >= 0.0)
         {
           // Successfully found xfrac, yfrac - compute weights
           bilinear_set_weights(xfrac, yfrac, weights);
-          bilinear_sort_weights(squareCorners.index, weights);
-          tgtValue = bilinear_remap(srcArray, weights, squareCorners.index);
+          bilinear_sort_weights(squareCorners.indices, weights);
+          tgtValue = bilinear_remap(srcArray, weights, squareCorners.indices);
         }
       else
         {
@@ -355,37 +352,31 @@ remap_bilinear_regular(RemapSearch &rsearch, const Varray<T1> &srcArray, const V
         }
     }
 
-  /*
-    Search for bilinear failed - use a distance-weighted average instead
-    (this is typically near the pole) Distance was stored in srcLats!
-  */
+  // Search for bilinear failed - use a distance-weighted average instead
+  // (this is typically near the pole) Distance was stored in srcLats!
   if (searchResult < 0)
     {
-      if (srcGridMask.size() == 0 || num_src_points(srcGridMask, squareCorners.index, squareCorners.lat) > 0)
+      if (srcGridMask.size() == 0 || num_src_points(srcGridMask, squareCorners.indices, squareCorners.lats) > 0)
         {
-          renormalize_weights(squareCorners.lat, weights);
-          bilinear_sort_weights(squareCorners.index, weights);
-          tgtValue = bilinear_remap(srcArray, weights, squareCorners.index);
+          renormalize_weights(squareCorners.lats, weights);
+          bilinear_sort_weights(squareCorners.indices, weights);
+          tgtValue = bilinear_remap(srcArray, weights, squareCorners.indices);
         }
     }
 }
 
 template <typename T1, typename T2>
 static void
-remap_bilinear_healpix(const RemapSearch &rsearch, const Varray<T1> &srcArray, const Varray<int8_t> &srcGridMask,
-                       const LonLatPoint &llpoint, T2 &tgtValue)
+remap_bilinear_healpix(const RemapSearch &rsearch, const Varray<T1> &srcArray, const Vmask &srcGridMask, const PointLonLat &pointLL,
+                       T2 &tgtValue)
 {
-  auto nside = rsearch.srcGrid->nside;
-  auto order = rsearch.srcGrid->order;
+  double weights[4];  // bilinear weights for four corners
+  size_t indices[4];  // indices for the four source points
 
-  double weights[4];  //  bilinear weights for four corners
-  size_t indices[4];  //  indices for the four source points
-
-  hp_bilinear_interpolate_weights(llpoint.lon, llpoint.lat, indices, weights, nside, order);
+  hp_bilinear_interpolate_weights(rsearch.srcGrid->hpParams, pointLL.get_lon(), pointLL.get_lat(), indices, weights);
 
   // Check to see if points are mask points
-  int searchResult = remap_check_mask_indices(indices, srcGridMask);
-
+  auto searchResult = remap_check_mask_indices(indices, srcGridMask);
   if (searchResult > 0)
     {
       bilinear_sort_weights(indices, weights);
@@ -393,7 +384,9 @@ remap_bilinear_healpix(const RemapSearch &rsearch, const Varray<T1> &srcArray, c
     }
 }
 
+// -----------------------------------------------------------------------
 // This routine computes and apply the weights for a bilinear interpolation.
+// -----------------------------------------------------------------------
 template <typename T1, typename T2>
 static void
 remap_bilinear(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissval, size_t numMissVals, RemapSearch &rsearch)
@@ -415,7 +408,7 @@ remap_bilinear(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissv
   auto tgtGridSize = tgtGrid->size;
   auto srcGridSize = srcGrid->size;
 
-  Varray<int8_t> srcGridMask;
+  Vmask srcGridMask;
   if (numMissVals) remap_set_mask(srcArray, srcGridSize, numMissVals, srcMissval, srcGridMask);
 
   // Compute mappings from source to target grid
@@ -423,26 +416,26 @@ remap_bilinear(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissv
   std::atomic<size_t> atomicCount{ 0 };
 
   // Loop over target grid
-
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
   for (size_t tgtCellIndex = 0; tgtCellIndex < tgtGridSize; ++tgtCellIndex)
     {
       atomicCount++;
-      if (cdo_omp_get_thread_num() == 0) progress.update((double) atomicCount / tgtGridSize);
+      auto ompthID = cdo_omp_get_thread_num();
+      if (ompthID == 0 && tgtGridSize > progressMinSize) progress.update((double) atomicCount / tgtGridSize);
 
       auto &tgtValue = tgtArray[tgtCellIndex];
       tgtValue = missval;
 
       if (!tgtGrid->mask[tgtCellIndex]) continue;
 
-      auto llpoint = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
+      auto pointLL = remapgrid_get_lonlat(tgtGrid, tgtCellIndex);
 
       if (isHealpixGrid)
-        remap_bilinear_healpix(rsearch, srcArray, srcGridMask, llpoint, tgtValue);
+        remap_bilinear_healpix(rsearch, srcArray, srcGridMask, pointLL, tgtValue);
       else
-        remap_bilinear_regular(rsearch, srcArray, srcGridMask, llpoint, tgtValue);
+        remap_bilinear_regular(rsearch, srcArray, srcGridMask, pointLL, tgtValue);
     }
 
   if (Options::cdoVerbose) cdo_print("%s: %.2f seconds", __func__, timer.elapsed());
@@ -451,8 +444,6 @@ remap_bilinear(const Varray<T1> &srcArray, Varray<T2> &tgtArray, double srcMissv
 void
 remap_bilinear(RemapSearch &remapSearch, const Field &field1, Field &field2)
 {
-  auto func = [&](const auto &v1, auto &v2, double missval, size_t numMissVals) {
-    remap_bilinear(v1, v2, missval, numMissVals, remapSearch);
-  };
-  field_operation2(func, field1, field2, field1.missval, field1.numMissVals);
+  auto func = [&](const auto &v1, auto &v2) { remap_bilinear(v1, v2, field1.missval, field1.numMissVals, remapSearch); };
+  field_operation2(func, field1, field2);
 }
